Re-exports
pub use agent::Agent;pub use error::AgentError;pub use openai::Model;pub use tool::Tool;pub use tool::ToolResult;
Modules
Macros
- function_
tool - A macro to create a function tool with automatic parameter schema generation
Attribute Macros
- tool_fn
- A procedural macro that generates a tool with parameter schema from a function signature